@@ -19,7 +19,7 @@ class OProgressBar():
         self.fill = fill
         self.printEnd = printEnd
 
-    def PrintProgess(self, progressState):
+    def PrintProgress(self, progressState):
         percent = ("{0:." + str(self.decimalPlaces) + "f}").format(100 * (progressState / float(self.completeState)))
         filledLength = int(self.length * progressState // self.completeState)
         bar = self.fill * filledLength + '-' * (self.length - filledLength)
